#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.5
visibility:           public
id:                   mighttpd2-4.0.5-HyUK3hm6TkAH7XfBNAsR62
key:                  mighttpd2-4.0.5-HyUK3hm6TkAH7XfBNAsR62
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  349b92fe15b6b517c8a409d30a4244f3
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mighttpd2-4.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.5-HyUK3hm6TkAH7XfBNAsR62
depends:
    array-0.5.6.0 async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu
    auto-update-0.1.6-BiK7zXEf7x11yi5UX3g5Dn base-4.18.2.1
    byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-A8CTHJLbf7AArK6CnJHSQw
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED
    conduit-extra-1.3.8-4LNkvIzwsWe54JJPbCmwjx
    dhall-1.42.3-JxVfcMLSqqkBWD0DRYSwKU directory-1.3.8.5
    filepath-1.4.300.1 http-date-0.0.11-GGzHVleigSSF0OJS6Em1WP
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb parsec-3.1.16.1
    resourcet-1.3.0-G1Jndw6mtoEGFSzuHCFgbA
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    streaming-commons-0.2.3.1-MBAvoCiutqJfVNhb5nEzw text-2.0.2
    unix-2.8.4.0 unix-time-0.4.17-EYnTI5w33YS1vnTxAEO4UG
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    wai-3.2.4-E4t208bIe9WGNSF4hxnMlb
    wai-app-file-cgi-3.1.12-Ae2ZoZeIQmEFgMXLhC7BKd
    warp-3.4.0-88S7teaxVGTKO5mHEdGrcO

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

